@@ -25,6 +25,10 @@
 #include <nm-setting-8021x.h>
 #endif
 
+#if !NM_CHECK_VERSION(1, 2, 0)
+#define NM_SETTING_802_1X_DOMAIN_SUFFIX_MATCH "domain-suffix-match"
+#endif
+
 #include <QtCore/QDebug>
 
 NetworkManager::Security8021xSettingPrivate::Security8021xSettingPrivate()
@@ -53,6 +57,7 @@ NetworkManager::Security8021xSetting::Security8021xSetting(const Ptr &other)
 {
     setEapMethods(other->eapMethods());
     setIdentity(other->identity());
+    setDomainSuffixMatch(other->domainSuffixMatch());
     setAnonymousIdentity(other->anonymousIdentity());
     setPacFile(other->pacFile());
     setCaCertificate(other->caCertificate());
@@ -136,6 +141,20 @@ QString NetworkManager::Security8021xSetting::anonymousIdentity() const
     return d->anonymousIdentity;
 }
 
+void NetworkManager::Security8021xSetting::setDomainSuffixMatch(const QString &domain)
+{
+    Q_D(Security8021xSetting);
+
+    d->domainSuffixMatch = domain;
+}
+
+QString NetworkManager::Security8021xSetting::domainSuffixMatch() const
+{
+    Q_D(const Security8021xSetting);
+
+    return d->domainSuffixMatch;
+}
+
 void NetworkManager::Security8021xSetting::setPacFile(const QString &filePath)
 {
     Q_D(Security8021xSetting);
@@ -650,6 +669,10 @@ void NetworkManager::Security8021xSetting::fromMap(const QVariantMap &setting)
         setAnonymousIdentity(setting.value(QLatin1String(NM_SETTING_802_1X_ANONYMOUS_IDENTITY)).toString());
     }
 
+    if (setting.contains(QLatin1String(NM_SETTING_802_1X_DOMAIN_SUFFIX_MATCH))) {
+        setDomainSuffixMatch(setting.value(QLatin1String(NM_SETTING_802_1X_DOMAIN_SUFFIX_MATCH)).toString());
+    }
+
     if (setting.contains(QLatin1String(NM_SETTING_802_1X_PAC_FILE))) {
         setPacFile(setting.value(QLatin1String(NM_SETTING_802_1X_PAC_FILE)).toString());
     }
@@ -853,6 +876,10 @@ QVariantMap NetworkManager::Security8021xSetting::toMap() const
         setting.insert(QLatin1String(NM_SETTING_802_1X_ANONYMOUS_IDENTITY), anonymousIdentity());
     }
 
+    if (!domainSuffixMatch().isEmpty()) {
+        setting.insert(QLatin1String(NM_SETTING_802_1X_DOMAIN_SUFFIX_MATCH), domainSuffixMatch());
+    }
+
     if (!pacFile().isEmpty()) {
         setting.insert(QLatin1String(NM_SETTING_802_1X_PAC_FILE), pacFile());
     }
@@ -891,7 +918,19 @@ QVariantMap NetworkManager::Security8021xSetting::toMap() const
 
     if (!version.isEmpty()) {
         setting.insert(QLatin1String(NM_SETTING_802_1X_PHASE1_PEAPVER), version);
-        setting.insert(QLatin1String(NM_SETTING_802_1X_PHASE1_PEAPLABEL), "1");
+    }
+
+    QString peapLabel;
+    switch (phase1PeapLabel()) {
+        case PeapLabelForce:
+            peapLabel = '1';
+            break;
+        case PeapLabelUnknown:
+            break;
+    }
+
+    if (!peapLabel.isEmpty()) {
+        setting.insert(QLatin1String(NM_SETTING_802_1X_PHASE1_PEAPLABEL), peapLabel);
     }
 
     QString provisioning;
@@ -1061,6 +1100,7 @@ QDebug NetworkManager::operator <<(QDebug dbg, const NetworkManager::Security802
     dbg.nospace() << NM_SETTING_802_1X_PAC_FILE << ": " << setting.pacFile() << '\n';
     dbg.nospace() << NM_SETTING_802_1X_CA_CERT << ": " << setting.caCertificate() << '\n';
     dbg.nospace() << NM_SETTING_802_1X_CA_PATH << ": " << setting.caPath() << '\n';
+    dbg.nospace() << NM_SETTING_802_1X_DOMAIN_SUFFIX_MATCH << ": " << setting.domainSuffixMatch() << '\n';
     dbg.nospace() << NM_SETTING_802_1X_SUBJECT_MATCH << ": " << setting.subjectMatch() << '\n';
     dbg.nospace() << NM_SETTING_802_1X_ALTSUBJECT_MATCHES << ": " << setting.altSubjectMatches() << '\n';
     dbg.nospace() << NM_SETTING_802_1X_CLIENT_CERT << ": " << setting.clientCertificate() << '\n';
